==> huaweicloudsdkcbr-3.1.99-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/batch_update_vault_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchUpdateVaultResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'updated_vaults_id': 'list[str]'
    }

    attribute_map = {
        'updated_vaults_id': 'updated_vaults_id'
    }

    def __init__(self, updated_vaults_id=None):
        """BatchUpdateVaultResponse

        The model defined in huaweicloud sdk

        :param updated_vaults_id: 已批量修改id列表
        :type updated_vaults_id: list[str]
        """
        
        super(BatchUpdateVaultResponse, self).__init__()

        self._updated_vaults_id = None
        self.discriminator = None

        if updated_vaults_id is not None:
            self.updated_vaults_id = updated_vaults_id

    @property
    def updated_vaults_id(self):
        """Gets the updated_vaults_id of this BatchUpdateVaultResponse.

        已批量修改id列表

        :return: The updated_vaults_id of this BatchUpdateVaultResponse.
        :rtype: list[str]
        """
        return self._updated_vaults_id

    @updated_vaults_id.setter
    def updated_vaults_id(self, updated_vaults_id):
        """Sets the updated_vaults_id of this BatchUpdateVaultResponse.

        已批量修改id列表

        :param updated_vaults_id: The updated_vaults_id of this BatchUpdateVaultResponse.
        :type updated_vaults_id: list[str]
        """
        self._updated_vaults_id = updated_vaults_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchUpdateVaultResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.1.146-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/batch_update_vault_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchUpdateVaultResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'updated_vaults_id': 'list[str]'
    }

    attribute_map = {
        'updated_vaults_id': 'updated_vaults_id'
    }

    def __init__(self, updated_vaults_id=None):
        r"""BatchUpdateVaultResponse

        The model defined in huaweicloud sdk

        :param updated_vaults_id: 已批量修改id列表
        :type updated_vaults_id: list[str]
        """
        
        super(BatchUpdateVaultResponse, self).__init__()

        self._updated_vaults_id = None
        self.discriminator = None

        if updated_vaults_id is not None:
            self.updated_vaults_id = updated_vaults_id

    @property
    def updated_vaults_id(self):
        r"""Gets the updated_vaults_id of this BatchUpdateVaultResponse.

        已批量修改id列表

        :return: The updated_vaults_id of this BatchUpdateVaultResponse.
        :rtype: list[str]
        """
        return self._updated_vaults_id

    @updated_vaults_id.setter
    def updated_vaults_id(self, updated_vaults_id):
        r"""Sets the updated_vaults_id of this BatchUpdateVaultResponse.

        已批量修改id列表

        :param updated_vaults_id: The updated_vaults_id of this BatchUpdateVaultResponse.
        :type updated_vaults_id: list[str]
        """
        self._updated_vaults_id = updated_vaults_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchUpdateVaultResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
